summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorDarrell Anderson <humanreadable@yahoo.com>2012-06-03 12:34:56 -0500
committerDarrell Anderson <humanreadable@yahoo.com>2012-06-03 12:34:56 -0500
commit2341ae8880b272c72ed13e079b883eb2f93a434a (patch)
tree00c1b7798c975b7b78fb5f4c70ed29216896ce74
parentf0641dec21948ce2769c020d47a0b5fbc4431e6e (diff)
downloadkoffice-2341ae8880b272c72ed13e079b883eb2f93a434a.tar.gz
koffice-2341ae8880b272c72ed13e079b883eb2f93a434a.zip
Branding cleanup: What's This help, KDE -> TDE
-rw-r--r--kchart/kchartBackgroundPixmapConfigPage.cc2
-rw-r--r--kexi/main/startup/KexiStartupFileDialog_win.cpp6
2 files changed, 4 insertions, 4 deletions
diff --git a/kchart/kchartBackgroundPixmapConfigPage.cc b/kchart/kchartBackgroundPixmapConfigPage.cc
index c0d3d70e..33bba83e 100644
--- a/kchart/kchartBackgroundPixmapConfigPage.cc
+++ b/kchart/kchartBackgroundPixmapConfigPage.cc
@@ -87,7 +87,7 @@ KChartBackgroundPixmapConfigPage::KChartBackgroundPixmapConfigPage( KChartParams
wallCB = new TQComboBox( false, this, "wallCombo" );
wallpaperLA->setBuddy(wallCB);
TQWhatsThis::add( wallCB, i18n( "You can select a background image from "
- "this list. Initially, the installed KDE "
+ "this list. Initially, the installed TDE "
"wallpapers will be offered. If you do not "
"find what you are looking for here, you can "
"select any image file by clicking on the "
diff --git a/kexi/main/startup/KexiStartupFileDialog_win.cpp b/kexi/main/startup/KexiStartupFileDialog_win.cpp
index 36b8c527..5550cf9f 100644
--- a/kexi/main/startup/KexiStartupFileDialog_win.cpp
+++ b/kexi/main/startup/KexiStartupFileDialog_win.cpp
@@ -207,7 +207,7 @@ void KexiStartupFileDialogBase::init(const TQString& startDir, const TQString& f
"Click on this button to open the bookmark menu where you may add, "
"edit or select a bookmark.<p>"
"These bookmarks are specific to the file dialog, but otherwise operate "
- "like bookmarks elsewhere in KDE.</qt>"));
+ "like bookmarks elsewhere in TDE.</qt>"));
connect( d->bookmarkHandler, TQT_SIGNAL( openURL( const TQString& )),
TQT_SLOT( enterURL( const TQString& )));
@@ -399,9 +399,9 @@ TQString KexiStartupFileDialogBase::currentFilter() const
{
//(js)filterWidget->currentFilter();
//we need to convert TQt filter format to KDE format
//TQt format: "some text (*.first *.second)" or "All (*)"
//KDE format: "*.first *.second" or "*"
TQString f = selectedFilter();
if (f.find('(')!=-1)
f = f.mid(f.find('(')+1);
@@ -399,9 +399,9 @@ TQString KexiStartupFileDialogBase::currentFilter() const
{
//(js)filterWidget->currentFilter();
- //we need to convert TQt filter format to KDE format
+ //we need to convert TQt filter format to TDE format
//TQt format: "some text (*.first *.second)" or "All (*)"
@@ -399,9 +399,9 @@ TQString KexiStartupFileDialogBase::currentFilter() const
//TQt format: "some text (*.first *.second)" or "All (*)"
- //KDE format: "*.first *.second" or "*"
+ //TDE format: "*.first *.second" or "*"
TQString f = selectedFilter();
if (f.find('(')!=-1)